@@ -101,6 +101,10 @@ class AirDogStatus(DeviceStatus):
 
 
 class AirDogX3(Device):
+    """Support for Airdog air purifiers (airdog.airpurifier.x*)."""
+
+    _supported_models = list(AVAILABLE_PROPERTIES.keys())
+
     @command(
         default_output=format_output(
             "",
