@@ -117,7 +117,7 @@ class GlobalContextObject:
 
 class DeviceGroupMeta(type):
 
-    device_classes: Set[Type] = set()
+    _device_classes: Set[Type] = set()
 
     def __new__(mcs, name, bases, namespace):
         commands = {}
@@ -150,7 +150,7 @@ class DeviceGroupMeta(type):
             namespace["get_device_group"] = classmethod(get_device_group)
 
         cls = super().__new__(mcs, name, bases, namespace)
-        mcs.device_classes.add(cls)
+        mcs._device_classes.add(cls)
         return cls
 
 
@@ -168,6 +168,30 @@ class DeviceGroup(click.MultiCommand):
             self.func = func
             func._device_group_command = self
             self.kwargs.setdefault("help", self.func.__doc__)
+
+            def _autodetect_model_if_needed(func):
+                def _wrap(self, *args, **kwargs):
+                    skip_autodetect = func._device_group_command.kwargs.pop(
+                        "skip_autodetect", False
+                    )
+                    if (
+                        not skip_autodetect
+                        and self._model is None
+                        and self._info is None
+                    ):
+                        _LOGGER.debug(
+                            "Unknown model, trying autodetection. %s %s"
+                            % (self._model, self._info)
+                        )
+                        self._fetch_info()
+                    return func(self, *args, **kwargs)
+
+                # TODO HACK to make the command visible to cli
+                _wrap._device_group_command = func._device_group_command
+                return _wrap
+
+            func = _autodetect_model_if_needed(func)
+
             return func
 
         @property
@@ -183,6 +207,9 @@ class DeviceGroup(click.MultiCommand):
             else:
                 output = format_output("Running command {0}".format(self.command_name))
 
+            # Remove skip_autodetect before constructing the click.command
+            self.kwargs.pop("skip_autodetect", None)
+
             func = output(func)
             for decorator in self.decorators:
                 func = decorator(func)
@@ -195,6 +222,7 @@ class DeviceGroup(click.MultiCommand):
     DEFAULT_PARAMS = [
         click.Option(["--ip"], required=True, callback=validate_ip),
         click.Option(["--token"], required=True, callback=validate_token),
+        click.Option(["--model"], required=False),
     ]
 
     def __init__(
